@@ -2333,7 +2333,10 @@ void GetPmake(enum OSTYPE OS, int ncpu, char *pmake)
 {
    if (ncpu == 0) ncpu = 1;
    if (CmndResults(NULL, "make -v | fgrep GNU")) /* using gnu make */
-      sprintf(pmake, "$(MAKE) -j %d", 2*ncpu);
+   {
+      if (ncpu == 1) sprintf(pmake, "$(MAKE) -j 2");
+      else sprintf(pmake, "$(MAKE) -j %d", ncpu);
+   }
    else
    {  /* AIX, HP-UX, SunOS make do not have parallel option */
       switch(OS)
@@ -3025,7 +3028,8 @@ void GoToTown()
    fprintf(fpout, "\n\n");
 
    fprintf(fpout, "   CC = %s\n", CC);
-   fprintf(fpout, "   CCFLAGS = $(CDEFS) %s\n", CCFLAGS);
+   fprintf(fpout, "   CCFLAG0 = %s\n", CCFLAGS);
+   fprintf(fpout, "   CCFLAGS = $(CDEFS) $(CCFLAG0)\n");
    fprintf(fpout, "   MCC = %s\n", MCC);
    fprintf(fpout, "   MMFLAGS = %s\n", MMFLAGS);
    fprintf(fpout, "   XCC = %s\n", XCC);
