@@ -48,7 +48,7 @@ static void trsmLU_2(const int N, const TYPE *A, TYPE *B, const int ldb)
    int j;
 
    p0 = B[2];
-   for (j=N; j; j--)
+   for (j=N-1; j; j--) /* stop 1 iteration early to stop prefetch */
    {
       xr2 = p0  ; xi2 = B[3];
       xr1 = *B  ; xi1 = B[1];
@@ -68,6 +68,21 @@ static void trsmLU_2(const int N, const TYPE *A, TYPE *B, const int ldb)
       B = bn;
       bn += ldb2;
    }
+   xr2 = p0  ; xi2 = B[3];
+   xr1 = *B  ; xi1 = B[1];
+
+   t0 = xr2;
+   xr2 = ar22*xr2 - ai22*xi2;
+   xi2 = ar22*xi2 + ai22*t0;
+
+   xr1 -= ar12*xr2 - ai12*xi2;
+   xi1 -= ar12*xi2 + ai12*xr2;
+   t0 = xr1;
+   xr1 = ar11*xr1 - ai11*xi1;
+   xi1 = ar11*xi1 + ai11*t0;
+
+   *B   = xr1; B[1] = xi1;
+   B[2] = xr2; B[3] = xi2;
 }
 static void trsmLU_3(const int N, const TYPE *A, TYPE *B, const int ldb)
 /*
@@ -87,7 +102,7 @@ static void trsmLU_3(const int N, const TYPE *A, TYPE *B, const int ldb)
    int j;
 
    p0 = B[4];
-   for (j=N; j; j--)
+   for (j=N-1; j; j--)
    {
       xr3 = p0  ; xi3 = B[5];
       xr1 = *B  ; xi1 = B[1];
@@ -117,6 +132,31 @@ static void trsmLU_3(const int N, const TYPE *A, TYPE *B, const int ldb)
       B = bn;
       bn += ldb2;
    }
+   xr3 = p0  ; xi3 = B[5];
+   xr1 = *B  ; xi1 = B[1];
+   xr2 = B[2]; xi2 = B[3];
+
+   t0 = xr3;
+   xr3 = ar33*xr3 - ai33*xi3;
+   xi3 = ar33*xi3 + ai33*t0;
+
+   xr2 -= ar23*xr3 - ai23*xi3;
+   xi2 -= ar23*xi3 + ai23*xr3;
+   t0 = xr2;
+   xr2 = ar22*xr2 - ai22*xi2;
+   xi2 = ar22*xi2 + ai22*t0;
+
+   xr1 -= ar13*xr3 - ai13*xi3;
+   xi1 -= ar13*xi3 + ai13*xr3;
+   xr1 -= ar12*xr2 - ai12*xi2;
+   xi1 -= ar12*xi2 + ai12*xr2;
+   t0 = xr1;
+   xr1 = ar11*xr1 - ai11*xi1;
+   xi1 = ar11*xi1 + ai11*t0;
+
+   *B   = xr1; B[1] = xi1;
+   B[2] = xr2; B[3] = xi2;
+   B[4] = xr3; B[5] = xi3;
 }
 static void trsmLU_4(const int N, const TYPE *A, TYPE *B, const int ldb)
 /*
@@ -139,7 +179,7 @@ static void trsmLU_4(const int N, const TYPE *A, TYPE *B, const int ldb)
    int j;
 
    p0 = B[6];
-   for (j=N; j; j--)
+   for (j=N-1; j; j--)
    {
       xr4 = p0  ; xi4 = B[7];
       xr1 = *B; xi1 = B[1];
@@ -181,6 +221,43 @@ static void trsmLU_4(const int N, const TYPE *A, TYPE *B, const int ldb)
       B = bn;
       bn += ldb2;
    }
+   xr4 = p0  ; xi4 = B[7];
+   xr1 = *B; xi1 = B[1];
+   xr3 = B[4]; xi3 = B[5];
+   xr2 = B[2]; xi2 = B[3];
+
+   t0 = xr4;
+   xr4 = ar44*xr4 - ai44*xi4;
+   xi4 = ar44*xi4 + ai44*t0;
+
+   xr3 -= ar34*xr4 - ai34*xi4;
+   xi3 -= ar34*xi4 + ai34*xr4;
+   t0 = xr3;
+   xr3 = ar33*xr3 - ai33*xi3;
+   xi3 = ar33*xi3 + ai33*t0;
+
+   xr2 -= ar24*xr4 - ai24*xi4;
+   xi2 -= ar24*xi4 + ai24*xr4;
+   xr2 -= ar23*xr3 - ai23*xi3;
+   xi2 -= ar23*xi3 + ai23*xr3;
+   t0 = xr2;
+   xr2 = ar22*xr2 - ai22*xi2;
+   xi2 = ar22*xi2 + ai22*t0;
+
+   xr1 -= ar14*xr4 - ai14*xi4;
+   xi1 -= ar14*xi4 + ai14*xr4;
+   xr1 -= ar13*xr3 - ai13*xi3;
+   xi1 -= ar13*xi3 + ai13*xr3;
+   xr1 -= ar12*xr2 - ai12*xi2;
+   xi1 -= ar12*xi2 + ai12*xr2;
+   t0 = xr1;
+   xr1 = ar11*xr1 - ai11*xi1;
+   xi1 = ar11*xi1 + ai11*t0;
+
+   *B   = xr1; B[1] = xi1;
+   B[2] = xr2; B[3] = xi2;
+   B[4] = xr3; B[5] = xi3;
+   B[6] = xr4; B[7] = xi4;
 }
 static void trsmLL_2(const int N, const TYPE *A, TYPE *B, const int ldb)
 /*
